@@ -93,9 +93,9 @@ checkFixedTime <- function(fixedTime, summariseMode) {
   }
 }
 
-checkDaysPriorHistory <- function(daysPriorHistory) {
+checkDaysPriorObservation <- function(daysPriorObservatio) {
   checkmate::assertIntegerish(
-    daysPriorHistory, lower = 0, any.missing = F, len = 1, null.ok = T
+    daysPriorObservatio, lower = 0, any.missing = F, len = 1, null.ok = T
   )
 }
 
@@ -108,9 +108,11 @@ checkGap <- function(gap) {
 }
 
 checkPriorUseWashout <- function(priorUseWashout) {
-  checkmate::assertIntegerish(
-    priorUseWashout, lower = 0, any.missing = F, len = 1
-  )
+  if (!(is.numeric(priorUseWashout) & length(priorUseWashout) == 1 & is.infinite(priorUseWashout))) {
+    checkmate::assertIntegerish(
+      priorUseWashout, lower = 0, any.missing = F, len = 1
+    )
+  }
 }
 
 checkCohortDateRange <- function(cohortDateRange) {
@@ -636,6 +638,18 @@ checkLabel <- function(label, binaryColumns) {
   )
 }
 
+checkCumulativeQuantity <- function(cumulativeQuantity, cohort) {
+  if (!is.logical(cumulativeQuantity) | length(cumulativeQuantity) != 1) {
+    cli::cli_warn("cumulativeQuantity must be TRUE or FALSE")
+  }
+}
+
+checkInitialQuantity <- function(initialQuantity, cohort) {
+  if (!is.logical(initialQuantity) | length(initialQuantity) != 1) {
+    cli::cli_warn("initialQuantity must be TRUE or FALSE")
+  }
+}
+
 # other functions
 checkColumns <- function(x, columns) {
   if (!all(columns %in% colnames(x))) {
@@ -669,7 +683,7 @@ checkConsistentCohortSet<- function(cs,
                                     missingDurationRange) {
   expectedColnames <- c(
     "cohort_definition_id", "cohort_name", "summarise_mode", "fixed_time",
-    "days_prior_history", "gap_era", "prior_use_washout",
+    "days_prior_observation", "gap_era", "prior_use_washout",
     "cohort_date_range_start", "cohort_date_range_end", "impute_duration",
     "duration_range_min", "duration_range_max"
   )
