@@ -21,6 +21,7 @@
 #' @param cdm 'cdm' object created with CDMConnector::cdm_from_con(). It must
 #' must contain the 'targetCohort' table and all the tables that we want to
 #' characterize. It is a compulsory input, no default value is provided.
+#' @param strata Stratification list
 #' @param window Temporal windows that we want to characterize. It must
 #' be a list of numeric vectors of length two. The tables will be characterized
 #' between the first element and the second element respect to the
@@ -58,19 +59,19 @@
 #' cdm <- mockDrugUtilisation()
 #'
 #' summariseLargeScaleCharacteristics(
-#'   cohort = cdm$cohort1, cdm = cdm,
+#'   cohort = cdm$cohort1,
 #'   tablesToCharacterize= c("drug_exposure", "condition_occurrence")
 #' )
 #' }
 #'
 summariseLargeScaleCharacteristics <- function(cohort,
-                                               cdm,
+                                               cdm = attr(cohort, "cdm_reference"),
+                                               strata = list(),
                                                window = list(
-                                                 c(-Inf, -366), c(-365, -91),
-                                                 c(-365, -31), c(-90, -1),
-                                                 c(-30, -1), c(0, 0), c(1, 30),
-                                                 c(1, 90), c(31, 365),
-                                                 c(91, 365), c(366, Inf)
+                                                 c(-Inf, -366), c(-365, -31),
+                                                 c(-30, -1), c(0, 0),
+                                                 c(1, 30), c(31, 365),
+                                                 c(366, Inf)
                                                ),
                                                tablesToCharacterize = c(
                                                  "condition_occurrence",
@@ -81,7 +82,7 @@ summariseLargeScaleCharacteristics <- function(cohort,
                                                overlap = TRUE,
                                                minCellCount = 5) {
   checkInputs(
-    cohort = cohort, cdm = cdm, window = window,
+    cohort = cohort, cdm = cdm, strata = strata, window = window,
     tablesToCharacterize = tablesToCharacterize, overlap = overlap,
     minCellCount = minCellCount
   )
@@ -102,7 +103,10 @@ summariseLargeScaleCharacteristics <- function(cohort,
 
   # compute denominator
   den <- cohort %>%
-    dplyr::select("cohort_definition_id", "subject_id", "cohort_start_date") %>%
+    dplyr::select(
+      "cohort_definition_id", "subject_id", "cohort_start_date",
+      dplyr::all_of(unique(unlist(strata)))
+    ) %>%
     dplyr::distinct() %>%
     dplyr::inner_join(
       cdm[["observation_period"]] %>%
@@ -127,8 +131,10 @@ summariseLargeScaleCharacteristics <- function(cohort,
               tablesToCharacterize[k]
             ), "end_date" = ifelse(
               overlap[k],
-              PatientProfiles::getEndName(
-                tablesToCharacterize[k]
+              ifelse(
+                is.na(PatientProfiles::getEndName(tablesToCharacterize[k])),
+                PatientProfiles::getStartName(tablesToCharacterize[k]),
+                PatientProfiles::getEndName(tablesToCharacterize[k])
               ),
               PatientProfiles::getStartName(
                 tablesToCharacterize[k]
@@ -157,7 +163,7 @@ summariseLargeScaleCharacteristics <- function(cohort,
       ) %>%
       dplyr::select(
         "cohort_definition_id", "subject_id", "cohort_start_date", "concept_id",
-        "start_dif", "end_dif"
+        "start_dif", "end_dif", dplyr::all_of(unique(unlist(strata)))
       ) %>%
       CDMConnector::computeQuery()
     for (i in 1:nrow(window)) {
@@ -170,14 +176,16 @@ summariseLargeScaleCharacteristics <- function(cohort,
         resultKI <- resultKI %>%
           dplyr::filter(.data$end_dif >= !!window$lower_bound[i])
       }
+      resultKI <- resultKI %>%
+        dplyr::select(
+          "cohort_definition_id", "subject_id", "cohort_start_date",
+          "concept_id", dplyr::all_of(unique(unlist(strata)))
+        ) %>%
+        dplyr::distinct() %>%
+        CDMConnector::computeQuery()
       result <- result %>%
         dplyr::union_all(
           resultKI %>%
-            dplyr::select(
-              "cohort_definition_id", "subject_id", "cohort_start_date",
-              "concept_id"
-            ) %>%
-            dplyr::distinct() %>%
             dplyr::group_by(.data$cohort_definition_id, .data$concept_id) %>%
             dplyr::summarise(count = dplyr::n(), .groups = "drop") %>%
             dplyr::inner_join(
@@ -187,10 +195,35 @@ summariseLargeScaleCharacteristics <- function(cohort,
             ) %>%
             dplyr::collect() %>%
             dplyr::mutate(
+              strata_name = "Overall", strata_level = "Overall",
               table_name = tablesToCharacterize[k],
               window_name = window$window_name[i]
             )
         )
+      for (j in seq_along(strata)) {
+        result <- result %>%
+          dplyr::union_all(
+            resultKI %>%
+              dplyr::mutate(
+                strata_level = !!rlang::parse_expr(sqlunite(strata[[j]]))
+              ) %>%
+              dplyr::group_by(
+                .data$cohort_definition_id, .data$concept_id, .data$strata_level
+              ) %>%
+              dplyr::summarise(count = dplyr::n(), .groups = "drop") %>%
+              dplyr::inner_join(
+                cdm[["concept"]] %>%
+                  dplyr::select("concept_id", "concept_name"),
+                by = "concept_id"
+              ) %>%
+              dplyr::collect() %>%
+              dplyr::mutate(
+                strata_name = names(strata)[j],
+                table_name = tablesToCharacterize[k],
+                window_name = window$window_name[i]
+              )
+          )
+      }
     }
   }
 
@@ -203,7 +236,7 @@ summariseLargeScaleCharacteristics <- function(cohort,
     ) %>%
     dplyr::select(
       "cohort_definition_id", "subject_id", "cohort_start_date", "start_dif",
-      "end_dif"
+      "end_dif", dplyr::all_of(unique(unlist(strata)))
     ) %>%
     CDMConnector::computeQuery()
   for (i in 1:nrow(window)) {
@@ -226,15 +259,36 @@ summariseLargeScaleCharacteristics <- function(cohort,
           dplyr::group_by(.data$cohort_definition_id) %>%
           dplyr::summarise(denominator_count = dplyr::n(), .groups = "drop") %>%
           dplyr::collect() %>%
-          dplyr::mutate(window_name = window$window_name[i], window_id = i)
+          dplyr::mutate(
+            strata_level = "Overall", strata_name = "Overall",
+            window_name = window$window_name[i], window_id = i
+          )
       )
+    for (j in seq_along(strata)) {
+      denominatorCount <- denominatorCount %>%
+        dplyr::union_all(
+          denI %>%
+            dplyr::mutate(
+              strata_level = !!rlang::parse_expr(sqlunite(strata[[j]]))
+            ) %>%
+            dplyr::group_by(
+              .data$cohort_definition_id, .data$strata_level
+            ) %>%
+            dplyr::summarise(denominator_count = dplyr::n(), .groups = "drop") %>%
+            dplyr::collect() %>%
+            dplyr::mutate(
+              strata_name = names(strata)[j],
+              window_name = window$window_name[i], window_id = i
+            )
+        )
+    }
   }
 
   # join all together
   result <- result %>%
     dplyr::inner_join(
       denominatorCount,
-      by = c("cohort_definition_id", "window_name")
+      by = c("cohort_definition_id", "window_name", "strata_level", "strata_name")
     ) %>%
     dplyr::mutate(
       "%" = 100 * .data$count / .data$denominator_count,
@@ -256,17 +310,13 @@ summariseLargeScaleCharacteristics <- function(cohort,
       .data$cohort_name, .data$table_name, .data$window_id, .data$concept_id
     ) %>%
     dplyr::mutate(
-      strata_name = "overall", strata_level = as.character(NA),
       cdm_name = dplyr::coalesce(CDMConnector::cdmName(cdm), as.character(NA)),
-      generated_by = paste0(
-        "DrugUtilisation_", utils::packageVersion("DrugUtilisation"),
-        "_summariseLargeScaleCharacteristics"
-      )
+      result_type = "Summary large scale characteristics"
     ) %>%
     dplyr::select(
       "cohort_name", "strata_name", "strata_level", "table_name", "window_name",
       "concept_id", "concept_name", "count", "denominator_count", "%",
-      "cdm_name", "generated_by"
+      "cdm_name", "result_type"
     )
 
 
@@ -313,11 +363,9 @@ summariseCharacteristicsFromCodelist <- function(cohort,
                                                  conceptSetList,
                                                  strata = list(),
                                                  window = list(
-                                                   c(-Inf, -366), c(-365, -91),
-                                                   c(-365, -31), c(-90, -1),
+                                                   c(-Inf, -366), c(-365, -31),
                                                    c(-30, -1), c(0, 0),
-                                                   c(1, 30), c(1, 90),
-                                                   c(31, 365), c(91, 365),
+                                                   c(1, 30), c(31, 365),
                                                    c(366, Inf)
                                                  ),
                                                  overlap = TRUE,
@@ -357,15 +405,20 @@ summariseCharacteristicsFromCodelist <- function(cohort,
       variable_type = "binary", variable_level = as.character(NA),
       estimate_type = "count", group_name = "Cohort name",
       cdm_name = dplyr::coalesce(CDMConnector::cdmName(cdm), as.character(NA)),
-      generated_by = paste0(
-        "DrugUtilisation_", utils::packageVersion("DrugUtilisation"),
-        "_summariseCharacteristicsFromCodelist"
+      result_type = "Summary characteristics from codelist"
+    ) %>%
+    dplyr::mutate(
+      "estimate" = dplyr::if_else(
+        .data$estimate_type %in% c("count","denominator_count") &
+          .data$estimate < minCellCount,
+        paste0("<", minCellCount),
+        as.character(.data$estimate)
       )
     ) %>%
     dplyr::select(
       "group_name", "group_level", "strata_name", "strata_level", "window_name",
       "variable", "variable_type", "variable_level", "estimate_type",
-      "estimate", "cdm_name", "generated_by"
+      "estimate", "cdm_name", "result_type"
     )
 
   return(result)
